@@ -72,6 +72,7 @@ ENVIRONMENT::ENVIRONMENT (GLOBALDATA *global):_global(global),done(NULL),fp(NULL
   waiting_sky = NULL;
   waiting_terrain = NULL;
   _global = global;
+  global_tank_index = 0;
 
   initialise ();
 }
@@ -156,48 +157,7 @@ This function loads environment settings from a text
 file. The function returns TRUE on success and FALSE if
 any erors are encountered.
 -- Jesse
-
-Changed to binary mode for ISO-C++ compliance
-the original method is below
--- Sven
 */
-int ENVIRONMENT::loadFromFile(ifstream &ifsFile)
-{
-  char chArea[NAME_LENGTH] = "";
-  double dData = 0.0;
-  bool bResult = true;
-  bool bIsFinished = false;
-  bool bIsData = false;
-
-  while (!bIsFinished && (bResult = popData(chArea, bIsData, ifsFile)))
-    {
-      if (!bIsData && !strcmp(chArea, FILEPART_ENDSECT)) bIsFinished  = true;
-      else if (!strcmp(chArea, "Wind Strength    ")) bResult = popData(windstrength,       ifsFile);
-      else if (!strcmp(chArea, "Wind Variation   ")) bResult = popData(windvariation,      ifsFile);
-      else if (!strcmp(chArea, "Viscosity        ")) bResult = popData(viscosity,          ifsFile);
-      else if (!strcmp(chArea, "Gravity          ")) bResult = popData(gravity,            ifsFile);
-      else if (!strcmp(chArea, "Weapon Tech Level")) bResult = popData(weapontechLevel,    ifsFile);
-      else if (!strcmp(chArea, "Item Tech Level  ")) bResult = popData(itemtechLevel,      ifsFile);
-      else if (!strcmp(chArea, "Meteors          ")) bResult = popData(meteors,            ifsFile);
-      else if (!strcmp(chArea, "Lightning        ")) bResult = popData(lightning,          ifsFile);
-      else if (!strcmp(chArea, "Satellite        ")) bResult = popData(satellite,          ifsFile);
-      else if (!strcmp(chArea, "Fog              ")) bResult = popData(fog,                ifsFile);
-      else if (!strcmp(chArea, "Land Type        ")) bResult = popData(landType,           ifsFile);
-      else if (!strcmp(chArea, "Land Slide Type  ")) bResult = popData(landSlideType,      ifsFile);
-      else if (!strcmp(chArea, "Land Slide Delay ")) bResult = popData(landSlideDelay,     ifsFile);
-      else if (!strcmp(chArea, "Falling Dirt Ball")) bResult = popData(falling_dirt_balls, ifsFile);
-      else if (!strcmp(chArea, "Wall Type        ")) bResult = popData(wallType,           ifsFile);
-      else if (!strcmp(chArea, "Boxed Mode       ")) bResult = popData(dBoxedMode,         ifsFile);
-      else if (!strcmp(chArea, "Fading Text      ")) bResult = popData(dFadingText,        ifsFile);
-      else if (!strcmp(chArea, "Shadowed Text    ")) bResult = popData(dShadowedText,      ifsFile);
-      else if (!strcmp(chArea, "Custom Background")) bResult = popData(custom_background,  ifsFile);
-      else if (!bIsFinished && bIsData)
-        bResult = popData(dData, ifsFile); // Something we do not know (any more/yet), so dump it!
-    }
-  return(bResult);
-}
-
-
 int ENVIRONMENT::loadFromFile_Text (FILE *file)
 {
   char line[MAX_CONFIG_LINE];
@@ -431,6 +391,7 @@ void ENVIRONMENT::newRound ()
 
   // time_to_fall = (rand() % MAX_GRAVITY_DELAY) + 1;
   time_to_fall = (rand() & (int)landSlideDelay) + 1;
+  global_tank_index = 0;
 }
 
 int ENVIRONMENT::ingamemenu ()
@@ -479,7 +440,7 @@ int ENVIRONMENT::ingamemenu ()
       if (keypressed ())
         {
           k = readkey ();
-          if (k >> 8 == KEY_ESC || k >> 8 == KEY_P)
+          if ( (k >> 8 == KEY_ESC) || (k >> 8 == KEY_P) )
             return (0);
         }
 
@@ -1040,29 +1001,39 @@ bool ENVIRONMENT::Get_Boxed_Mode(GLOBALDATA *global)
 
 TANK *ENVIRONMENT::Get_Next_Tank(int *wrapped_around)
 {
-   static int index = 0;
+   int index;
    int found = FALSE;
    int old_index;
+   int wrapped = 0;
 
+   index = global_tank_index;
    old_index = index;
-   do
+   index++;
+   while (!found)
    {
-      index++;
-      if (index >= MAXPLAYERS)
-      {
-         index = 0;
-         *wrapped_around = TRUE;
-      }
-      if (order[index])
-          found = TRUE;      // found a tank
-   } while ( (! found) && (old_index != index) );
- 
+        if (index >= MAXPLAYERS)
+        {
+             index = 0;
+             *wrapped_around = TRUE;
+             wrapped++;
+        }
+        if ( (order[index]) && (index != old_index) )
+        {
+             found = TRUE;
+        }
+        else
+           index++;
+        if (wrapped > 1)
+           break;
+   }
+
    /* 
    if (! found)
       *wrapped_around = TRUE;
    else
       *wrapped_around = FALSE;
    */
+   global_tank_index = index;
    return order[index];
 }
 
