@@ -204,7 +204,8 @@ int game (GLOBALDATA *global, ENVIRONMENT *env)
               shooting_tank = missile->Check_SDI(global);
               if (shooting_tank)
               {
-                  (shooting_tank->x < missile->x) ? angle_to_fire = 135 : angle_to_fire = 225;
+                  // (shooting_tank->x < missile->x) ? angle_to_fire = 135 : angle_to_fire = 225;
+                  angle_to_fire = atan2(labs(shooting_tank->y - 10 - missile->y), (missile->x - shooting_tank->x)) * 180 / 3.14159265 + 90;
                   defense_beam = new BEAM(global, env, shooting_tank->x, shooting_tank->y - 10, angle_to_fire, SML_LAZER);
                   missile->trigger();
               }
@@ -535,6 +536,8 @@ int game (GLOBALDATA *global, ENVIRONMENT *env)
                 done = TRUE;
              screen_update = FALSE;
          }
+         if (global->close_button_pressed)
+             done = TRUE;
     }    // end of game loop
 
     // credit winners
@@ -547,7 +550,8 @@ int game (GLOBALDATA *global, ENVIRONMENT *env)
          readkey();     // clear the buffer
 
     // check to see if we have a winner or we just bailed out early
-    if (winner != -1)
+    if ( (winner != -1) && (! global->demo_mode) && 
+         (! global->close_button_pressed) )
     {
           showRoundEndScoresAt(global, env, env->db, global->screenWidth / 2,
                                global->screenHeight / 2, winner);
