@@ -912,6 +912,8 @@ int GLOBALDATA::Load_Text_Files()
         strcpy(suffix, "_ru.txt");
      else if (language == LANGUAGE_SPANISH)
         strcpy(suffix, "_ES.txt");
+     else if (language == LANGUAGE_ITALIAN)
+        strcpy(suffix, "_it.txt");
      else
         strcpy(suffix, ".txt");       // default to english
 
